@@ -16,8 +16,8 @@ public:
   InternalEnergy(const double &rs_,
                  const double &yMin_,
                  const double &yMax_,
-                 const Interpolator1D &ssfi_,
-                 Integrator1D &itg_)
+                 std::shared_ptr<Interpolator1D> ssfi_,
+                 std::shared_ptr<Integrator1D> itg_)
       : rs(rs_),
         yMin(yMin_),
         yMax(yMax_),
@@ -37,19 +37,16 @@ private:
   const double yMax;
 
   // Integrator object
-  Integrator1D &itg;
+  const std::shared_ptr<Integrator1D> itg;
 
   // Static structure factor interpolator
-  const Interpolator1D &ssfi;
+  const std::shared_ptr<Interpolator1D> ssfi;
 
   // Integrand
   double integrand(const double &y) const;
 
   // Compute static structure factor
   double ssf(const double &y) const;
-
-  // Constant for unit conversion
-  const double lambda = pow(4.0 / (9.0 * M_PI), 1.0 / 3.0);
 };
 
 #endif
