@@ -4,7 +4,7 @@ using namespace std;
 using ItgParam = Integrator1D::Param;
 using ItgType = Integrator1D::Type;
 
-double Rdf::ssf(const double &y) const { return ssfi.eval(y); }
+double Rdf::ssf(const double &y) const { return ssfi->eval(y); }
 
 double Rdf::integrand(const double &y) const {
   if (y > cutoff) return 0;
@@ -15,10 +15,10 @@ double Rdf::integrand(const double &y) const {
 double Rdf::get() const {
   auto func = [&](const double &y) -> double { return integrand(y); };
   if (r == 0) {
-    itg.compute(func, ItgParam(0.0, cutoff));
-    return 1 + 1.5 * itg.getSolution();
+    itg->compute(func, ItgParam(0.0, cutoff));
+    return 1 + 1.5 * itg->getSolution();
   } else {
-    itgf.compute(func, ItgParam(r));
-    return 1 + 1.5 * itgf.getSolution() / r;
+    itgf->compute(func, ItgParam(r));
+    return 1 + 1.5 * itgf->getSolution() / r;
   }
 }
