@@ -24,11 +24,6 @@ int VSBase::compute() {
   }
 }
 
-void VSBase::init() {
-  initScheme();
-  initFreeEnergyIntegrand();
-}
-
 const vector<vector<double>> &VSBase::getFreeEnergyIntegrand() const {
   assert(thermoProp);
   return thermoProp->getFreeEnergyIntegrand();
@@ -39,11 +34,6 @@ const vector<double> &VSBase::getFreeEnergyGrid() const {
   return thermoProp->getFreeEnergyGrid();
 }
 
-const vector<double> &VSBase::getAlpha() const {
-  assert(thermoProp);
-  return thermoProp->getAlpha();
-}
-
 void VSBase::doIterations() {
   auto func = [this](const double &alphaTmp) -> double {
     return alphaDifference(alphaTmp);
@@ -67,19 +57,18 @@ double VSBase::alphaDifference(const double &alphaTmp) {
 // ThermoPropBase class
 // -----------------------------------------------------------------
 
-ThermoPropBase::ThermoPropBase(const VSInput &inVS, const RpaInput &inRpa) {
+ThermoPropBase::ThermoPropBase(const VSInput &inVS, const Input &inRpa) {
   // Check if we are solving for particular state points
   isZeroCoupling = (inRpa.getCoupling() == 0.0);
   isZeroDegeneracy = (inRpa.getDegeneracy() == 0.0);
   // Set variables related to the free energy calculation
   setRsGrid(inVS, inRpa);
   setFxcIntegrand(inVS);
-  setAlpha(inVS);
   setFxcIdxTargetStatePoint(inRpa);
   setFxcIdxUnsolvedStatePoint();
 }
 
-void ThermoPropBase::setRsGrid(const VSInput &inVS, const RpaInput &inRpa) {
+void ThermoPropBase::setRsGrid(const VSInput &inVS, const Input &inRpa) {
   const double &rs = inRpa.getCoupling();
   const double &drs = inVS.getCouplingResolution();
   if (!numUtil::isZero(remainder(rs, drs))) {
@@ -118,22 +107,7 @@ void ThermoPropBase::setFxcIntegrand(const VSInput &in) {
   }
 }
 
-void ThermoPropBase::setAlpha(const VSInput &in) {
-  // Initialize
-  const size_t nrs = rsGrid.size();
-  alpha.resize(nrs);
-  // Set free parameter if passed in input
-  const auto &fxciData = in.getFreeEnergyIntegrand();
-  if (!fxciData.grid.empty()) {
-    const double rsMaxi = fxciData.grid.back();
-    for (size_t i = 0; i < nrs; ++i) {
-      const double &rs = rsGrid[i];
-      if (rs <= rsMaxi) { alpha[i] = fxciData.alpha[i]; }
-    }
-  }
-}
-
-void ThermoPropBase::setFxcIdxTargetStatePoint(const RpaInput &in) {
+void ThermoPropBase::setFxcIdxTargetStatePoint(const Input &in) {
   auto isTarget = [&](const double &rs) {
     return numUtil::equalTol(rs, in.getCoupling());
   };
@@ -190,7 +164,7 @@ void ThermoPropBase::compute() {
   assert(structProp);
   structProp->compute();
   const vector<double> fxciTmp = structProp->getFreeEnergyIntegrand();
-  const double alphaTmp = structProp->getAlpha();
+  alpha = structProp->getAlpha();
   const size_t &idx = fxcIdxTargetStatePoint;
   fxcIntegrand[THETA_DOWN][idx - 1] = fxciTmp[SIdx::RS_DOWN_THETA_DOWN];
   fxcIntegrand[THETA_DOWN][idx] = fxciTmp[SIdx::RS_THETA_DOWN];
@@ -201,9 +175,6 @@ void ThermoPropBase::compute() {
   fxcIntegrand[THETA_UP][idx - 1] = fxciTmp[SIdx::RS_DOWN_THETA_UP];
   fxcIntegrand[THETA_UP][idx] = fxciTmp[SIdx::RS_THETA_UP];
   fxcIntegrand[THETA_UP][idx + 1] = fxciTmp[SIdx::RS_UP_THETA_UP];
-  alpha[idx - 1] = alphaTmp;
-  alpha[idx] = alphaTmp;
-  alpha[idx + 1] = alphaTmp;
 }
 
 const vector<double> &ThermoPropBase::getSsf() {
